# Generated by Django 5.0.2 on 2024-07-23 18:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isapilib', '0003_userapi_is_admin_alter_apilogs_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='apilogs',
            name='response_time',
            field=models.IntegerField(default=0),
        ),
    ]
